==> android-aihelp-aar-3.3.12-sources.jar: net/aihelp/common/API.java <==
package net.aihelp.common;

public class API {

    // api
    public static String REQUEST_SCHEME = "https://";
    public static String HOST_URL = "aihelp.net";

    public static String INIT_URL = "/elva/api/v3.0/initget";
    public static String FAQ_URL = "/elva/api/v3.0/faqs";
    public static String OP_URL = "/elva/api/v3.0/faqs1";
    public static String FORM_URL = "/elva/api/v3.0/faqs2";
    public static String CRM_TOKEN_URL = "/elva/api/v3.0/crmtoken";
    public static String M_FAQ_URL = "/sdk_faq/src/index.html";
    public static String UPLOAD_URL = "/FileService/api/upload";
    public static String UPLOAD_VIDEO_URL = "/elva/api/uploadapi/video";
    public static String UPLOAD_FILE_URL = "/elva/api/uploadapi/file";
    public static String FAQ_FEEDBACK_URL = "/elva/api/v3.0/faqfeedback/like";
    public static String FETCH_NEW_MSG = "/elva/api/v3.0/message/fetch";
    public static String GET_LAST_CONVERSATION = "/elva/api/v3.0/sdk/history";
    public static String SYNC_VIP_INFO = "/elva/api/v3.0/vipinfo";
    public static String GENERATE_NEW_TICKET = "/elva/api/v3.0/sdk/ticketcreate";
    public static String TRANSLATE_MESSAGE = "/elva/api/translate/search";
    public static String ASK_FOR_RESOLVE_STATUS = "/elva/api/sdk/resolve";
    public static String GET_USER_TOKEN = "/elva/api/v3.0/sdk/getusertoken";

    public static String LOG_COUNT_URL = "/elva/api/v3.0/point";
    public static String LOG_DAU_URL = "/elva/api/v3.0/initset";
    public static String LOG_NETWORK_RESULT_SENT = "/elva/api/v3.0/sdk/chatnetwork";
    public static String TRACK_EXCEPTION = "/elva/api/sdktrack/exceptiontrack";

    public static String TRACK_COLLECT = "/elva/api/v3.0/sdktrack/collect";

    public static String CDN_URL = "https://cdn.aihelp.net/Elva";
    public static String CONFIG_FILE_URL = "";

    public static String LOCALE_FILE_URL = "";

    // custom configs
    public static String CONFIG_STYLE_SHEET_URL = "";
    public static String CONFIG_BUSINESS_LOGIC_URL = "";
    public static String CONFIG_OPINION_URL = "";
    public static String CONFIG_FAQ_HOT_TOPIC_URL = "";
    public static String CONFIG_PROCESS_URL = "";
    public static String CONFIG_TEXT_URL = "";

    // mqtt
    public static String MQTT_IP = "wss142.aihelp.net";
    public static String MQTT_PORT = "1883";
    public static String MQTT_TOPIC = "topic";
    public static String MQTT_FAQ_IP = MQTT_IP;
    public static String MQTT_FAQ_PORT = MQTT_PORT;

    public static final String TOPIC_LOGIN = "login";
    public static final String TOPIC_LOGOUT = "logout";
    public static final String TOPIC_BOT_CHAT = "alice.message.chat";
    public static final String TOPIC_BOT_FAQ = "alice.faq.like";
    public static final String TOPIC_CONVERSATION_SEND = "chat.private";
    public static final String TOPIC_CONVERSATION_RECEIVE = "pushChat";
    public static final String TOPIC_CONVERSATION_FINISHED = "pushOverflagChat";
    public static final String TOPIC_CONVERSATION_EVALUATE = "alice.chat.evaluate";
    public static final String TOPIC_SUBMIT_FORM = "pushFormChat";
    public static final String TOPIC_SUBMIT_ORDER = "pushOrderChat";
    public static final String TOPIC_FAQ_NOTIFICATION = "pushSdkMessage";
    public static final String TOPIC_WITHDRAW = "pushWithdraw";
    public static final String TOPIC_TICKET_REJECTED = "ticketRejected";

}

==> android-aihelp-aar-3.5.4-sources.jar: net/aihelp/common/API.java <==
package net.aihelp.common;

public class API {

    // api
    public static String REQUEST_SCHEME = "https://";
    public static String HOST_URL = "aihelp.net";

    public static String INIT_URL = "/elva/api/v3.0/initget";
    public static String FAQ_URL = "/elva/api/v3.0/faqs";
    public static String OP_URL = "/elva/api/v3.0/faqs1";
    public static String FORM_URL = "/elva/api/v3.0/faqs2";
    public static String CRM_TOKEN_URL = "/elva/api/v3.0/crmtoken";
    public static String M_FAQ_URL = "/sdk_faq/src/index.html";

    public static String UPLOAD_IMAGE_URL = "/FileService/api/upload";
    public static String UPLOAD_VIDEO_URL = "/elva/api/uploadapi/video";
    public static String UPLOAD_LOG_URL = "/elva/api/uploadapi/file";
    public static String UPLOAD_ATTACHMENT_URL = "/elva/api/uploadapi/file";

    public static String FAQ_FEEDBACK_URL = "/elva/api/v3.0/faqfeedback/like";
    public static String FETCH_NEW_MSG = "/elva/api/v3.0/message/fetch";
    public static String GET_LAST_CONVERSATION = "/elva/api/v3.0/sdk/history";
    public static String SYNC_VIP_INFO = "/elva/api/v3.0/vipinfo";
    public static String GENERATE_NEW_TICKET = "/elva/api/v3.0/sdk/ticketcreate";
    public static String TRANSLATE_MESSAGE = "/elva/api/translate/search";
    public static String ASK_FOR_RESOLVE_STATUS = "/elva/api/sdk/resolve";
    public static String GET_USER_TOKEN = "/elva/api/v3.0/sdk/getusertoken";

    public static String LOG_COUNT_URL = "/elva/api/v3.0/point";
    public static String LOG_DAU_URL = "/elva/api/v3.0/initset";
    public static String LOG_NETWORK_RESULT_SENT = "/elva/api/v3.0/sdk/chatnetwork";
    public static String TRACK_EXCEPTION = "/elva/api/sdktrack/exceptiontrack";

    public static String TRACK_COLLECT = "/elva/api/v3.0/sdktrack/collect";

    public static String CDN_URL = "https://cdn.aihelp.net/Elva";
    public static String CONFIG_FILE_URL = "";

    public static String LOCALE_FILE_URL = "";

    public static String TICKET_UNREAD_STATUS = "/sdk/api/v4.0/taskcenter/unread";
    public static String TICKET_LIST = "/sdk/api/v4.0/taskcenter/list";
    public static String TICKET_CONTENT = "/sdk/api/v4.0/taskcenter/detail";
    public static String TICKET_MESSAGE = "/sdk/api/v4.0/taskcenter/message";

    // custom configs
    public static String CONFIG_STYLE_SHEET_URL = "";
    public static String CONFIG_BUSINESS_LOGIC_URL = "";
    public static String CONFIG_OPINION_URL = "";
    public static String CONFIG_FAQ_HOT_TOPIC_URL = "";
    public static String CONFIG_PROCESS_URL = "";
    public static String CONFIG_TEXT_URL = "";

    // mqtt
    public static String MQTT_IP = "wss142.aihelp.net";
    public static String MQTT_PORT = "1883";
    public static String MQTT_TOPIC = "topic";
    public static String MQTT_FAQ_IP = MQTT_IP;
    public static String MQTT_FAQ_PORT = MQTT_PORT;

    public static final String TOPIC_LOGIN = "login";
    public static final String TOPIC_LOGOUT = "logout";
    public static final String TOPIC_BOT_CHAT = "alice.message.chat";
    public static final String TOPIC_BOT_FAQ = "alice.faq.like";
    public static final String TOPIC_CONVERSATION_SEND = "chat.private";
    public static final String TOPIC_CONVERSATION_RECEIVE = "pushChat";
    public static final String TOPIC_CONVERSATION_FINISHED = "pushOverflagChat";
    public static final String TOPIC_CONVERSATION_EVALUATE = "alice.chat.evaluate";
    public static final String TOPIC_SUBMIT_FORM = "pushFormChat";
    public static final String TOPIC_SUBMIT_ORDER = "pushOrderChat";
    public static final String TOPIC_FAQ_NOTIFICATION = "pushSdkMessage";
    public static final String TOPIC_WITHDRAW = "pushWithdraw";
    public static final String TOPIC_TICKET_REJECTED = "ticketRejected";

}
